@@ -34,7 +34,7 @@ class CacheableSprite(pygame.sprite.Sprite):
     def __init__(self, layer : int):
         self._layer  = layer
         super(CacheableSprite, self).__init__()
- 
+
     def kill(self) -> None:
         # remove sprite from all groups
         super().kill()
@@ -51,19 +51,19 @@ class AnimatedSprite(CacheableSprite):
 
         self.images = list()
 
-        for imgName in imageFileList:
-            surf = PygameGlobal.get_game().load_image(imgName).convert()
+        for img_name in imageFileList:
+            surf = PygameGlobal.get_game().load_image(img_name).convert()
             surf.set_colorkey(transparentBackgroundColor, RLEACCEL)
             self.images.append( surf )
 
         self.surf = self.images[0]
         self.rect = self.surf.get_rect(center = initPos)
         self.current_frame = -1
-        
+
     # draws the buffer on the current screen buffer.
     def draw_on_buffer(self, game : 'PyGame') -> None:
         self.current_frame = (self.current_frame + 1) % len(self.images)
-        game.screen.blit(self.images[ self.current_frame ], self.rect)      
+        game.screen.blit(self.images[ self.current_frame ], self.rect)
 
 
 # sprite wrapping class
@@ -81,10 +81,10 @@ class ImageSprite(CacheableSprite):
 
     # draws the buffer on the current screen buffer.
     def draw_on_buffer(self, game : 'PyGame') -> None:
-        game.screen.blit(self.surf, self.rect)      
+        game.screen.blit(self.surf, self.rect)
+
+
 
-   
-   
 
 
 
@@ -102,13 +102,13 @@ class PyGame:
 
         if "width" in kwargs:
             self.display_width = kwargs["width"]
-        else:    
+        else:
             self.display_width = 800
 
 
         if "height" in kwargs:
             self.display_height = kwargs["height"]
-        else:    
+        else:
             self.display_height = 600
 
 
@@ -145,7 +145,7 @@ class PyGame:
         self.map_file_to_sound = dict()
         self.map_file_to_image = dict()
         self.map_type_to_spritecache = dict()
-        
+
 
         # Setup for sounds, defaults are good
         pygame.mixer.init()
@@ -160,28 +160,28 @@ class PyGame:
 
 
     # add event handler
-    def add_event_handler(self, eventType, handlerFunc : Callable[['PyGame'], None]) -> None:
-        self.event_handler[ eventType ] = handlerFunc
+    def add_event_handler(self, event_type, handler_func : Callable[['PyGame'], None]) -> None:
+        self.event_handler[ event_type ] = handler_func
 
     # add key down event handler
-    def add_key_down_event(self, key : int, handlerFunc : Callable[['PyGame'], None]) -> None:
-        self.key_down_handlers[ key ] = handlerFunc
+    def add_key_down_event(self, key : int, handler_func : Callable[['PyGame'], None]) -> None:
+        self.key_down_handlers[ key ] = handler_func
 
     # add key up event handler
-    def add_key_up_event(self, key : int, handlerFunc: Callable[['PyGame'], None]) -> None:
-        self.key_up_handlers[ key ] = handlerFunc
+    def add_key_up_event(self, key : int, handler_func: Callable[['PyGame'], None]) -> None:
+        self.key_up_handlers[ key ] = handler_func
 
     # add key pressed handler, is being called on each frame if the key is still pressed.
-    def add_key_pressed_event(self, key : int, handlerFunc: Callable[['PyGame'], None]) -> None:
-        self.key_pressed_handlers[ key ] = handlerFunc
+    def add_key_pressed_event(self, key : int, handler_func: Callable[['PyGame'], None]) -> None:
+        self.key_pressed_handlers[ key ] = handler_func
 
-    # add a timer event, the handlerFunc function argument will be called once per timeInMillisecond milliseconds.
-    def add_timer_event(self, timeInMillisecond : int, handlerFunc: Callable[['PyGame'], None]) -> None:
-        timerVal = self.last_timer_event
-        self.add_event_handler( timerVal, handlerFunc)
-        pygame.time.set_timer(timerVal, timeInMillisecond)
+    # add a timer event, the handler_func function argument will be called once per time_in_millisecond milliseconds.
+    def add_timer_event(self, time_in_millisecond : int, handler_func: Callable[['PyGame'], None]) -> None:
+        timer_val = self.last_timer_event
+        self.add_event_handler( timer_val, handler_func)
+        pygame.time.set_timer(timer_val, time_in_millisecond)
         self.last_timer_event += 1
-        return timerVal
+        return timer_val
 
 
     # add a sprite the the group of all sprites, Note that the sprite is being rendered according to its layer (see ImageSprite init)
@@ -191,9 +191,9 @@ class PyGame:
     # run the game loop
     def run(self) -> None:
         while self.running:
-            
+
             # start of frame, draw the empty stage  here.
-            self.on_start_frame()        
+            self.on_start_frame()
 
             # handle all events
             for event in pygame.event.get():
@@ -201,19 +201,19 @@ class PyGame:
                     if event.key in self.key_down_handlers:
                         handler = self.key_down_handlers[event.key]
                         handler(self)
-                        
+
                 elif event.type == KEYUP:
                     if event.key in self.key_up_handlers:
                         handler = self.key_up_handlers[event.key]
                         handler(self)
-                        
+
                 elif event.type in self.event_handler:
                     handler = self.event_handler[event.type]
                     handler(self)
 
                 elif event.type == pygame.QUIT:
-                     self.exit()
-                     continue
+                    self.exit()
+                    continue
 
             pressed_keys = pygame.key.get_pressed()
 
@@ -232,19 +232,19 @@ class PyGame:
             # draw all sprites for this frame on the current buffer (the current buffer is not visible)
             for entity in self.all_sprites:
                 entity.draw_on_buffer(self)
-      
+
             # make current buffer visible.
             pygame.display.flip()
 
             self.on_colission_test()
-    
+
             self.clock.tick(self.framerate)
 
         #pygame.quit()
 
     # calling this function will cause the game loop to exit, provided that run has been called earlier.
     def exit(self) -> None:
-        self.running = False    
+        self.running = False
 
     # called on the beginning of each frame; here you can override to fill in the backgraound picture.
     def on_start_frame(self) -> None:
@@ -266,35 +266,35 @@ class PyGame:
         self.bgcolor = bgcolor
 
     # print a line of text on the screen
-    def print(self, x : int, y : int,  *args) -> None:
+    def print(self, pos_x : int, pos_y : int,  *args) -> None:
         msg = ' '.join(map(str, args))
         text_surface = self.font.render(msg, True, self.fgcolor, self.bgcolor)
-        self.screen.blit(text_surface, (x, y))
+        self.screen.blit(text_surface, (pos_x, pos_y))
 
 
     # print a lot of text on the screen, text that does not fit the line is shown on the next line.
-    def print_text(self, x : int, y : int, *args) -> None:
+    def print_text(self, pos_x : int, pos_y : int, *args) -> None:
 
         msg = ' '.join(map(str, args))
 
         space = self.font.size(' ')[0]  # The width of a space.
-        cur_x, cur_y = x, y
+        cur_x, cur_y = pos_x, pos_y
         for line in str(msg).splitlines():
-            for w in line.split(" "):
-                word_surface = self.font.render(w, 0, self.fgcolor)
+            for word in line.split(" "):
+                word_surface = self.font.render(word, 0, self.fgcolor)
                 word_width, word_height = word_surface.get_size()
                 if cur_x + word_width >= self.display_width:
-                    cur_x = x  # Reset the x.
+                    cur_x = pos_x  # Reset the x.
                     cur_y += word_height  # Start on new row.
                 self.screen.blit(word_surface, (cur_x, cur_y))
                 cur_x += word_width + space
-            cur_x = x  # Reset the x.
+            cur_x = pos_x  # Reset the x.
             cur_y += word_height  # Start on new row.
 
-         
+
     # print text on the screen, wait for the user to spress space
     def print_dialog(self, *args) -> None:
-        
+
         self.screen.fill((135, 206, 250))
         self.print_text(0,0, *args)
         self.print(0, self.display_height - self.font_size, "Press Space To Continue")
@@ -308,34 +308,34 @@ class PyGame:
                     break
             self.clock.tick(30)
 
-    def load_image(self, fileName : str) -> None:
-        if not fileName in self.map_file_to_image:
-            image = pygame.image.load(fileName)
-            if image == None:
-                print("Can't load image file", fileName)
-            self.map_file_to_image[ fileName ] = image
+    def load_image(self, file_name : str) -> None:
+        if not file_name in self.map_file_to_image:
+            image = pygame.image.load(file_name)
+            if image is None:
+                print("Can't load image file", file_name)
+            self.map_file_to_image[ file_name ] = image
             return image
-        
-        return self.map_file_to_image[ fileName ] 
 
-    def play_sound(self, fileName : str, loops : int = 0) -> None:
-        if not fileName in self.map_file_to_sound:
-            sound = pygame.mixer.Sound(fileName)
-            self.map_file_to_sound[ fileName ] = sound
+        return self.map_file_to_image[ file_name ]
+
+    def play_sound(self, file_name : str, loops : int = 0) -> None:
+        if not file_name in self.map_file_to_sound:
+            sound = pygame.mixer.Sound(file_name)
+            self.map_file_to_sound[ file_name ] = sound
         else:
-            sound = self.map_file_to_sound[ fileName ]
+            sound = self.map_file_to_sound[ file_name ]
 
-        if sound != None:
+        if sound is not None:
             sound.play(loops)
         else:
-            print("sound: ", fileName, "not found!")
+            print("sound: ", file_name, "not found!")
 
-    def play_background_sound(self, fileName : str) -> None:
-        self.play_sound(fileName, -1)
+    def play_background_sound(self, file_name : str) -> None:
+        self.play_sound(file_name, -1)
 
     def stop_all_sounds(self):
-        for k,v in self.map_file_to_sound.items():
-            v.stop()
+        for val in self.map_file_to_sound.values():
+            val.stop()
 
     def get_cached_sprite(self, sprite_class : Type) -> None:
         type_name = str(sprite_class)
@@ -352,15 +352,15 @@ class PyGame:
 
         # check if sprite is cacheable - it is if it has the reuse method
         reuse_method = getattr(sprite,"reuse", None)
-        if reuse_method != None and callable(reuse_method):
+        if reuse_method is not None and callable(reuse_method):
 
             # this trick returns the type of the sprites derived class.
             type_name = str(sprite.__class__)
 
             # get per sprite type cache
-            if not type_name in self.map_type_to_spritecache:
+            if type_name not in self.map_type_to_spritecache:
                 self.map_type_to_spritecache[ type_name ] = list()
-            
+
             sprite_cache = self.map_type_to_spritecache[ type_name ]
 
             # check if cache is not too big.
@@ -368,14 +368,3 @@ class PyGame:
 
                 # cache the sprite
                 sprite_cache.append(sprite)
-                
-            
-
-
-
-
-
-            
-            
-
-         
